@@ -213,6 +213,7 @@ class AsyncSearchClient(NamespacedClient):
             "pit",
             "post_filter",
             "profile",
+            "project_routing",
             "query",
             "rescore",
             "runtime_mappings",
@@ -295,7 +296,7 @@ class AsyncSearchClient(NamespacedClient):
             t.Union[t.Mapping[str, t.Any], t.Sequence[t.Mapping[str, t.Any]]]
         ] = None,
         rest_total_hits_as_int: t.Optional[bool] = None,
-        routing: t.Optional[str] = None,
+        routing: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         runtime_mappings: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         script_fields: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         search_after: t.Optional[
@@ -533,8 +534,6 @@ class AsyncSearchClient(NamespacedClient):
             __query["preference"] = preference
         if pretty is not None:
             __query["pretty"] = pretty
-        if project_routing is not None:
-            __query["project_routing"] = project_routing
         if q is not None:
             __query["q"] = q
         if request_cache is not None:
@@ -592,6 +591,8 @@ class AsyncSearchClient(NamespacedClient):
                 __body["post_filter"] = post_filter
             if profile is not None:
                 __body["profile"] = profile
+            if project_routing is not None:
+                __body["project_routing"] = project_routing
             if query is not None:
                 __body["query"] = query
             if rescore is not None:
