@@ -23,16 +23,16 @@ from ._base import NamespacedClient
 from .utils import (
     SKIP_IN_PATH,
     Stability,
+    _availability_warning,
     _quote,
     _rewrite_parameters,
-    _stability_warning,
 )
 
 
 class NodesClient(NamespacedClient):
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def clear_repositories_metering_archive(
         self,
         *,
@@ -44,15 +44,18 @@ class NodesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Clear the archived repositories metering. Clear the archived repositories metering
-        information in the cluster.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/clear-repositories-metering-archive-api.html>`_
+          <p>Clear the archived repositories metering.</p>
+          <p>Clear the archived repositories metering information in the cluster.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-clear-repositories-metering-archive>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
-            information. All the nodes selective options are explained [here](https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster.html#cluster-nodes).
-        :param max_archive_version: Specifies the maximum [archive_version](https://www.elastic.co/guide/en/elasticsearch/reference/current/get-repositories-metering-api.html#get-repositories-metering-api-response-body)
-            to be cleared from the archive.
+            information.
+        :param max_archive_version: Specifies the maximum `archive_version` to be cleared
+            from the archive.
         """
         if node_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'node_id'")
@@ -83,7 +86,7 @@ class NodesClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def get_repositories_metering_info(
         self,
         *,
@@ -94,16 +97,18 @@ class NodesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get cluster repositories metering. Get repositories metering information for
-        a cluster. This API exposes monotonically non-decreasing counters and it is expected
-        that clients would durably store the information needed to compute aggregations
-        over a period of time. Additionally, the information exposed by this API is volatile,
-        meaning that it will not be present after node restarts.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-repositories-metering-api.html>`_
+          <p>Get cluster repositories metering.</p>
+          <p>Get repositories metering information for a cluster.
+          This API exposes monotonically non-decreasing counters and it is expected that clients would durably store the information needed to compute aggregations over a period of time.
+          Additionally, the information exposed by this API is volatile, meaning that it will not be present after node restarts.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-get-repositories-metering-info>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
-            information. All the nodes selective options are explained [here](https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster.html#cluster-nodes).
+            information.
         """
         if node_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'node_id'")
@@ -138,7 +143,6 @@ class NodesClient(NamespacedClient):
         human: t.Optional[bool] = None,
         ignore_idle_threads: t.Optional[bool] = None,
         interval: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
-        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         snapshots: t.Optional[int] = None,
         sort: t.Optional[
@@ -151,21 +155,21 @@ class NodesClient(NamespacedClient):
         ] = None,
     ) -> TextApiResponse:
         """
-        Get the hot threads for nodes. Get a breakdown of the hot threads on each selected
-        node in the cluster. The output is plain text with a breakdown of the top hot
-        threads for each node.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/cluster-nodes-hot-threads.html>`_
+          <p>Get the hot threads for nodes.</p>
+          <p>Get a breakdown of the hot threads on each selected node in the cluster.
+          The output is plain text with a breakdown of the top hot threads for each node.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-hot-threads>`_
 
         :param node_id: List of node IDs or names used to limit returned information.
         :param ignore_idle_threads: If true, known idle threads (e.g. waiting in a socket
             select, or to get a task from an empty queue) are filtered out.
         :param interval: The interval to do the second sampling of threads.
-        :param master_timeout: Period to wait for a connection to the master node. If
-            no response is received before the timeout expires, the request fails and
-            returns an error.
         :param snapshots: Number of samples of thread stacktrace.
-        :param sort: The sort order for 'cpu' type (default: total)
+        :param sort: The sort order for 'cpu' type
         :param threads: Specifies the number of hot threads to provide information for.
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
@@ -189,8 +193,6 @@ class NodesClient(NamespacedClient):
             __query["ignore_idle_threads"] = ignore_idle_threads
         if interval is not None:
             __query["interval"] = interval
-        if master_timeout is not None:
-            __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
         if snapshots is not None:
@@ -218,29 +220,71 @@ class NodesClient(NamespacedClient):
         self,
         *,
         node_id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        metric: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        metric: t.Optional[
+            t.Union[
+                t.Sequence[
+                    t.Union[
+                        str,
+                        t.Literal[
+                            "_all",
+                            "_none",
+                            "aggregations",
+                            "http",
+                            "indices",
+                            "ingest",
+                            "jvm",
+                            "os",
+                            "plugins",
+                            "process",
+                            "remote_cluster_server",
+                            "settings",
+                            "thread_pool",
+                            "transport",
+                        ],
+                    ]
+                ],
+                t.Union[
+                    str,
+                    t.Literal[
+                        "_all",
+                        "_none",
+                        "aggregations",
+                        "http",
+                        "indices",
+                        "ingest",
+                        "jvm",
+                        "os",
+                        "plugins",
+                        "process",
+                        "remote_cluster_server",
+                        "settings",
+                        "thread_pool",
+                        "transport",
+                    ],
+                ],
+            ]
+        ] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         flat_settings: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get node information. By default, the API returns all attributes and core settings
-        for cluster nodes.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/cluster-nodes-info.html>`_
+          <p>Get node information.</p>
+          <p>By default, the API returns all attributes and core settings for cluster nodes.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-info>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
             information.
         :param metric: Limits the information returned to the specific metrics. Supports
             a comma-separated list, such as http,ingest.
         :param flat_settings: If true, returns settings in flat format.
-        :param master_timeout: Period to wait for a connection to the master node. If
-            no response is received before the timeout expires, the request fails and
-            returns an error.
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
         """
@@ -266,8 +310,6 @@ class NodesClient(NamespacedClient):
             __query["flat_settings"] = flat_settings
         if human is not None:
             __query["human"] = human
-        if master_timeout is not None:
-            __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
         if timeout is not None:
@@ -298,20 +340,18 @@ class NodesClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Reload the keystore on nodes in the cluster. Secure settings are stored in an
-        on-disk keystore. Certain of these settings are reloadable. That is, you can
-        change them on disk and reload them without restarting any nodes in the cluster.
-        When you have updated reloadable secure settings in your keystore, you can use
-        this API to reload those settings on each node. When the Elasticsearch keystore
-        is password protected and not simply obfuscated, you must provide the password
-        for the keystore when you reload the secure settings. Reloading the settings
-        for the whole cluster assumes that the keystores for all nodes are protected
-        with the same password; this method is allowed only when inter-node communications
-        are encrypted. Alternatively, you can reload the secure settings on each node
-        by locally accessing the API and passing the node-specific Elasticsearch keystore
-        password.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/secure-settings.html#reloadable-secure-settings>`_
+          <p>Reload the keystore on nodes in the cluster.</p>
+          <p>Secure settings are stored in an on-disk keystore. Certain of these settings are reloadable.
+          That is, you can change them on disk and reload them without restarting any nodes in the cluster.
+          When you have updated reloadable secure settings in your keystore, you can use this API to reload those settings on each node.</p>
+          <p>When the Elasticsearch keystore is password protected and not simply obfuscated, you must provide the password for the keystore when you reload the secure settings.
+          Reloading the settings for the whole cluster assumes that the keystores for all nodes are protected with the same password; this method is allowed only when inter-node communications are encrypted.
+          Alternatively, you can reload the secure settings on each node by locally accessing the API and passing the node-specific Elasticsearch keystore password.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-reload-secure-settings>`_
 
         :param node_id: The names of particular nodes in the cluster to target.
         :param secure_settings_password: The password for the Elasticsearch keystore.
@@ -360,8 +400,120 @@ class NodesClient(NamespacedClient):
         self,
         *,
         node_id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        metric: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        index_metric: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        metric: t.Optional[
+            t.Union[
+                t.Sequence[
+                    t.Union[
+                        str,
+                        t.Literal[
+                            "_all",
+                            "_none",
+                            "adaptive_selection",
+                            "allocations",
+                            "breaker",
+                            "discovery",
+                            "fs",
+                            "http",
+                            "indexing_pressure",
+                            "indices",
+                            "ingest",
+                            "jvm",
+                            "os",
+                            "process",
+                            "repositories",
+                            "script",
+                            "script_cache",
+                            "thread_pool",
+                            "transport",
+                        ],
+                    ]
+                ],
+                t.Union[
+                    str,
+                    t.Literal[
+                        "_all",
+                        "_none",
+                        "adaptive_selection",
+                        "allocations",
+                        "breaker",
+                        "discovery",
+                        "fs",
+                        "http",
+                        "indexing_pressure",
+                        "indices",
+                        "ingest",
+                        "jvm",
+                        "os",
+                        "process",
+                        "repositories",
+                        "script",
+                        "script_cache",
+                        "thread_pool",
+                        "transport",
+                    ],
+                ],
+            ]
+        ] = None,
+        index_metric: t.Optional[
+            t.Union[
+                t.Sequence[
+                    t.Union[
+                        str,
+                        t.Literal[
+                            "_all",
+                            "bulk",
+                            "completion",
+                            "dense_vector",
+                            "docs",
+                            "fielddata",
+                            "flush",
+                            "get",
+                            "indexing",
+                            "mappings",
+                            "merge",
+                            "query_cache",
+                            "recovery",
+                            "refresh",
+                            "request_cache",
+                            "search",
+                            "segments",
+                            "shard_stats",
+                            "sparse_vector",
+                            "store",
+                            "translog",
+                            "warmer",
+                        ],
+                    ]
+                ],
+                t.Union[
+                    str,
+                    t.Literal[
+                        "_all",
+                        "bulk",
+                        "completion",
+                        "dense_vector",
+                        "docs",
+                        "fielddata",
+                        "flush",
+                        "get",
+                        "indexing",
+                        "mappings",
+                        "merge",
+                        "query_cache",
+                        "recovery",
+                        "refresh",
+                        "request_cache",
+                        "search",
+                        "segments",
+                        "shard_stats",
+                        "sparse_vector",
+                        "store",
+                        "translog",
+                        "warmer",
+                    ],
+                ],
+            ]
+        ] = None,
         completion_fields: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         error_trace: t.Optional[bool] = None,
         fielddata_fields: t.Optional[t.Union[str, t.Sequence[str]]] = None,
@@ -371,23 +523,24 @@ class NodesClient(NamespacedClient):
         human: t.Optional[bool] = None,
         include_segment_file_sizes: t.Optional[bool] = None,
         include_unloaded_segments: t.Optional[bool] = None,
-        level: t.Optional[
-            t.Union[str, t.Literal["cluster", "indices", "shards"]]
-        ] = None,
-        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        level: t.Optional[t.Union[str, t.Literal["indices", "node", "shards"]]] = None,
         pretty: t.Optional[bool] = None,
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         types: t.Optional[t.Sequence[str]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get node statistics. Get statistics for nodes in a cluster. By default, all stats
-        are returned. You can limit the returned information by using metrics.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/cluster-nodes-stats.html>`_
+          <p>Get node statistics.</p>
+          <p>Get statistics for nodes in a cluster.
+          By default, all stats are returned. You can limit the returned information by using metrics.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-stats>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
             information.
-        :param metric: Limit the information returned to the specified metrics
+        :param metric: Limits the information returned to the specific metrics.
         :param index_metric: Limit the information returned for indices metric to the
             specific index metrics. It can be used only if indices (or all) metric is
             specified.
@@ -404,11 +557,8 @@ class NodesClient(NamespacedClient):
             are requested).
         :param include_unloaded_segments: If `true`, the response includes information
             from segments that are not loaded into memory.
-        :param level: Indicates whether statistics are aggregated at the cluster, index,
-            or shard level.
-        :param master_timeout: Period to wait for a connection to the master node. If
-            no response is received before the timeout expires, the request fails and
-            returns an error.
+        :param level: Indicates whether statistics are aggregated at the node, indices,
+            or shards level.
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
         :param types: A comma-separated list of document types for the indexing index
@@ -467,8 +617,6 @@ class NodesClient(NamespacedClient):
             __query["include_unloaded_segments"] = include_unloaded_segments
         if level is not None:
             __query["level"] = level
-        if master_timeout is not None:
-            __query["master_timeout"] = master_timeout
         if pretty is not None:
             __query["pretty"] = pretty
         if timeout is not None:
@@ -490,7 +638,14 @@ class NodesClient(NamespacedClient):
         self,
         *,
         node_id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        metric: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        metric: t.Optional[
+            t.Union[
+                t.Sequence[
+                    t.Union[str, t.Literal["_all", "aggregations", "rest_actions"]]
+                ],
+                t.Union[str, t.Literal["_all", "aggregations", "rest_actions"]],
+            ]
+        ] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
@@ -498,15 +653,18 @@ class NodesClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get feature usage information.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/cluster-nodes-usage.html>`_
+          <p>Get feature usage information.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-nodes-usage>`_
 
         :param node_id: A comma-separated list of node IDs or names to limit the returned
-            information; use `_local` to return information from the node you're connecting
-            to, leave empty to get information from all nodes
+            information. Use `_local` to return information from the node you're connecting
+            to, leave empty to get information from all nodes.
         :param metric: Limits the information returned to the specific metrics. A comma-separated
-            list of the following options: `_all`, `rest_actions`.
+            list of the following options: `_all`, `rest_actions`, `aggregations`.
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
         """
