@@ -31,7 +31,7 @@ class TextStructureClient(NamespacedClient):
         *,
         field: str,
         index: str,
-        column_names: t.Optional[str] = None,
+        column_names: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         delimiter: t.Optional[str] = None,
         documents_to_sample: t.Optional[int] = None,
         ecs_compatibility: t.Optional[t.Union[str, t.Literal["disabled", "v1"]]] = None,
@@ -217,7 +217,7 @@ class TextStructureClient(NamespacedClient):
         self,
         *,
         messages: t.Optional[t.Sequence[str]] = None,
-        column_names: t.Optional[str] = None,
+        column_names: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         delimiter: t.Optional[str] = None,
         ecs_compatibility: t.Optional[t.Union[str, t.Literal["disabled", "v1"]]] = None,
         error_trace: t.Optional[bool] = None,
@@ -398,7 +398,7 @@ class TextStructureClient(NamespacedClient):
         text_files: t.Optional[t.Sequence[t.Any]] = None,
         body: t.Optional[t.Sequence[t.Any]] = None,
         charset: t.Optional[str] = None,
-        column_names: t.Optional[str] = None,
+        column_names: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         delimiter: t.Optional[str] = None,
         ecs_compatibility: t.Optional[str] = None,
         explain: t.Optional[bool] = None,
