@@ -312,8 +312,7 @@ class LicenseClient(NamespacedClient):
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-license-post-start-basic>`_
 
-        :param acknowledge: whether the user has acknowledged acknowledge messages (default:
-            false)
+        :param acknowledge: Whether the user has acknowledged acknowledge messages
         :param master_timeout: Period to wait for a connection to the master node.
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
@@ -360,8 +359,8 @@ class LicenseClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Start a trial.
-          Start a 30-day trial, which gives access to all subscription features.</p>
+          <p>Start a trial.</p>
+          <p>Start a 30-day trial, which gives access to all subscription features.</p>
           <p>NOTE: You are allowed to start a trial only if your cluster has not already activated a trial for the current major product version.
           For example, if you have already activated a trial for v8.0, you cannot start a new trial until v9.0. You can, however, request an extended trial at <a href="https://www.elastic.co/trialextension">https://www.elastic.co/trialextension</a>.</p>
           <p>To check the status of your trial, use the get trial status API.</p>
@@ -369,10 +368,9 @@ class LicenseClient(NamespacedClient):
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-license-post-start-trial>`_
 
-        :param acknowledge: whether the user has acknowledged acknowledge messages (default:
-            false)
+        :param acknowledge: Whether the user has acknowledged acknowledge messages
         :param master_timeout: Period to wait for a connection to the master node.
-        :param type: The type of trial license to generate (default: "trial")
+        :param type: The type of trial license to generate
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_license/start_trial"
